==> Products.CMFPlacefulWorkflow-3.0.2.tar.gz: Products.CMFPlacefulWorkflow-3.0.2/setup.py <==
from setuptools import find_packages
from setuptools import setup


version = "3.0.2"


setup(
    name="Products.CMFPlacefulWorkflow",
    version=version,
    description="Workflow policies for Plone",
    # Note: long_description is in setup.cfg
    # to avoid needing workarounds for UnicodeDecodeErrors.
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Framework :: Plone",
        "Framework :: Plone :: 6.0",
        "Framework :: Plone :: Core",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
    ],
    keywords="CMF Plone Zope2 workflow",
    author="Encolpe DEGOUTE",
    author_email="plone-developers@lists.sourceforge.net",
    url="https://github.com/plone/Products.CMFPlacefulWorkflow",
    license="GPL",
    packages=find_packages(),
    namespace_packages=["Products"],
    include_package_data=True,
    zip_safe=False,
    python_requires=">=3.8",
    extras_require=dict(
        test=[
            "plone.app.contenttypes",
            "plone.app.testing",
            "plone.testing",
            "transaction",
        ],
    ),
    install_requires=[
        "AccessControl",
        "Acquisition",
        "plone.base",
        "Persistence",
        "Products.CMFCore",
        "Products.CMFPlone",
        "Products.GenericSetup",
        "setuptools",
        "Zope",
        "zope.component",
        "zope.i18nmessageid",
        "zope.interface",
    ],
)

==> Products.CMFPlacefulWorkflow-3.0.3.tar.gz: Products.CMFPlacefulWorkflow-3.0.3/setup.py <==
from setuptools import find_packages
from setuptools import setup


version = "3.0.3"


setup(
    name="Products.CMFPlacefulWorkflow",
    version=version,
    description="Workflow policies for Plone",
    # Note: long_description is in setup.cfg
    # to avoid needing workarounds for UnicodeDecodeErrors.
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Framework :: Plone",
        "Framework :: Plone :: 6.0",
        "Framework :: Plone :: Core",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
    ],
    keywords="CMF Plone Zope2 workflow",
    author="Encolpe DEGOUTE",
    author_email="plone-developers@lists.sourceforge.net",
    url="https://github.com/plone/Products.CMFPlacefulWorkflow",
    license="GPL",
    packages=find_packages(),
    namespace_packages=["Products"],
    include_package_data=True,
    zip_safe=False,
    python_requires=">=3.8",
    extras_require=dict(
        test=[
            "plone.app.contenttypes[test]",
            "plone.app.testing",
            "plone.testing",
            "transaction",
        ],
    ),
    install_requires=[
        "AccessControl",
        "Acquisition",
        "plone.base",
        "Persistence",
        "Products.CMFCore",
        "Products.CMFPlone",
        "Products.GenericSetup",
        "setuptools",
        "Zope",
        "zope.component",
        "zope.i18nmessageid",
        "zope.interface",
    ],
)
